/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.tencent.devops.process.engine.service

import com.tencent.devops.common.api.pojo.ErrorType
import com.tencent.devops.common.api.util.JsonUtil
import com.tencent.devops.common.api.util.timestampmilli
import com.tencent.devops.common.pipeline.enums.BuildStatus
import com.tencent.devops.common.pipeline.pojo.element.ElementAdditionalOptions
import com.tencent.devops.process.engine.dao.PipelineBuildTaskDao
import com.tencent.devops.process.pojo.task.PipelineBuildTaskInfo
import org.jooq.DSLContext
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service

@Service
class PipelineBuildTaskService @Autowired constructor(
    private val dslContext: DSLContext,
    private val pipelineBuildTaskDao: PipelineBuildTaskDao
) {
    fun getAllBuildTask(buildId: String): List<PipelineBuildTaskInfo> {
        val list = pipelineBuildTaskDao.getByBuildId(dslContext, buildId)
        return list.map {
            with(it) {
                PipelineBuildTaskInfo(
                    projectId = projectId,
                    pipelineId = pipelineId,
                    buildId = buildId,
                    stageId = stageId,
                    containerId = containerId,
                    containerHashId = containerHashId,
                    containerType = containerType,
                    taskSeq = taskSeq,
                    taskId = taskId,
                    taskName = taskName,
                    taskType = taskType,
                    taskAtom = taskAtom,
                    status = BuildStatus.values()[status],
                    taskParams = JsonUtil.toMutableMapSkipEmpty(taskParams),
                    additionalOptions = JsonUtil.toOrNull(additionalOptions, ElementAdditionalOptions::class.java),
                    executeCount = executeCount ?: 1,
                    starter = starter,
                    approver = approver,
                    subBuildId = subBuildId,
                    startTime = startTime?.timestampmilli() ?: 0L,
                    endTime = endTime?.timestampmilli() ?: 0L,
                    errorType = if (errorType == null) null else ErrorType.values()[errorType],
                    errorCode = errorCode,
                    errorMsg = errorMsg
                )
            }
        }
    }
}