/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.tencent.devops.project.service.impl

import com.tencent.devops.common.auth.api.AuthProjectApi
import com.tencent.devops.common.auth.api.AuthResourceApi
import com.tencent.devops.common.auth.api.AuthResourceType
import com.tencent.devops.common.auth.api.pojo.ResourceRegisterInfo
import com.tencent.devops.common.auth.code.BK_DEVOPS_SCOPE
import com.tencent.devops.common.auth.code.GLOBAL_SCOPE_TYPE
import com.tencent.devops.common.auth.code.ProjectAuthServiceCode
import com.tencent.devops.project.service.ProjectPermissionService
import org.springframework.beans.factory.annotation.Autowired

class BluekingProjectPermissionServiceImpl @Autowired constructor(
    private val authProjectApi: AuthProjectApi,
    private val authResourceApi: AuthResourceApi,
    private val projectAuthServiceCode: ProjectAuthServiceCode
) : ProjectPermissionService {

    override fun verifyUserProjectPermission(accessToken: String?, projectCode: String, userId: String): Boolean {
        val projectCodes = authProjectApi.getUserProjects(
            serviceCode = projectAuthServiceCode,
            userId = userId,
            supplier = null
        )
        return projectCodes.contains(projectCode)
    }

    override fun getUserProjectsAvailable(userId: String): Map<String, String> {
        return authProjectApi.getUserProjectsAvailable(
            serviceCode = projectAuthServiceCode,
            userId = userId,
            supplier = null
        )
    }

    override fun getUserProjects(userId: String): List<String> {
        return authProjectApi.getUserProjects(
            serviceCode = projectAuthServiceCode,
            userId = userId,
            supplier = null
        )
    }

    override fun modifyResource(projectCode: String, projectName: String) {
        authResourceApi.modifyResource(
            scopeType = GLOBAL_SCOPE_TYPE,
            serviceCode = projectAuthServiceCode,
            resourceType = AuthResourceType.PROJECT,
            projectCode = BK_DEVOPS_SCOPE,
            resourceCode = projectCode,
            resourceName = projectName
        )
    }

    override fun deleteResource(projectCode: String) {
        authResourceApi.deleteResource(
            scopeType = GLOBAL_SCOPE_TYPE,
            serviceCode = projectAuthServiceCode,
            resourceType = AuthResourceType.PROJECT,
            projectCode = BK_DEVOPS_SCOPE,
            resourceCode = projectCode
        )
    }

    override fun createResources(
        userId: String,
        accessToken: String?,
        resourceRegisterInfo: ResourceRegisterInfo
    ): String {
        val projectList = mutableListOf<ResourceRegisterInfo>()
        projectList.add(resourceRegisterInfo)
        authResourceApi.batchCreateResource(
            scopeType = GLOBAL_SCOPE_TYPE,
            scopeId = BK_DEVOPS_SCOPE,
            systemId = projectAuthServiceCode,
            resourceType = AuthResourceType.PROJECT,
            resourceList = projectList,
            principalId = userId
        )
        return ""
    }
}