/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.tencent.devops.repository.api

import com.tencent.devops.common.api.auth.AUTH_HEADER_USER_ID
import com.tencent.devops.common.api.auth.AUTH_HEADER_USER_ID_DEFAULT_VALUE
import com.tencent.devops.common.api.enums.RepositoryType
import com.tencent.devops.common.api.enums.ScmType
import com.tencent.devops.common.api.pojo.Page
import com.tencent.devops.common.api.pojo.Result
import com.tencent.devops.repository.pojo.Repository
import com.tencent.devops.repository.pojo.RepositoryId
import com.tencent.devops.repository.pojo.RepositoryInfo
import com.tencent.devops.repository.pojo.RepositoryInfoWithPermission
import com.tencent.devops.repository.pojo.RepositoryPage
import com.tencent.devops.repository.pojo.commit.CommitResponse
import com.tencent.devops.repository.pojo.enums.Permission
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import io.swagger.annotations.ApiParam
import javax.ws.rs.Consumes
import javax.ws.rs.DELETE
import javax.ws.rs.GET
import javax.ws.rs.HeaderParam
import javax.ws.rs.POST
import javax.ws.rs.PUT
import javax.ws.rs.Path
import javax.ws.rs.PathParam
import javax.ws.rs.Produces
import javax.ws.rs.QueryParam
import javax.ws.rs.core.MediaType

@Api(tags = ["USER_REPOSITORY"], description = "用户-代码库")
@Path("/user/repositories")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
interface UserRepositoryResource {

    @ApiOperation("是否拥有创建代码库权限")
    @Path("/{projectId}/hasCreatePermission")
    @GET
    fun hasCreatePermission(
        @ApiParam("用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String
    ): Result<Boolean>

    @ApiOperation("是否拥有创建代码库别名")
    @Path("/{projectId}/hasAliasName")
    @GET
    fun hasAliasName(
        @ApiParam("用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = false)
        @QueryParam("repositoryHashId")
        repositoryHashId: String?,
        @ApiParam("代码库别名", required = true)
        @QueryParam("aliasName")
        aliasName: String
    ): Result<Boolean>

    @ApiOperation("关联代码库")
    @POST
    @Path("/{projectId}/")
    fun create(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam(value = "代码库模型", required = true)
        repository: Repository
    ): Result<RepositoryId>

    @ApiOperation("获取代码库详情")
    @GET
    @Path("/{projectId}/{repositoryId}/")
    fun get(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = true)
        @PathParam("repositoryId")
        repositoryId: String,
        @ApiParam("代码库请求类型", required = true)
        @QueryParam("repositoryType")
        repositoryType: RepositoryType?
    ): Result<Repository>

    @ApiOperation("编辑关联代码库")
    @PUT
    @Path("/{projectId}/{repositoryHashId}/")
    fun edit(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = true)
        @PathParam("repositoryHashId")
        repositoryHashId: String,
        @ApiParam(value = "代码库模型", required = true)
        repository: Repository
    ): Result<Boolean>

    @ApiOperation("代码库列表")
    @GET
    @Path("/{projectId}/")
    fun list(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("仓库类型", required = false)
        @QueryParam("repositoryType")
        repositoryType: ScmType?,
        @ApiParam("第几页", required = false, defaultValue = "1")
        @QueryParam("page")
        page: Int?,
        @ApiParam("每页多少条", required = false, defaultValue = "20")
        @QueryParam("pageSize")
        pageSize: Int?
    ): Result<RepositoryPage<RepositoryInfoWithPermission>>

    @ApiOperation("代码库列表根据别名模糊查询")
    @GET
    @Path("/{projectId}/search/")
    fun fuzzySearchByAliasName(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("仓库类型", required = false)
        @QueryParam("repositoryType")
        repositoryType: ScmType?,
        @ApiParam("仓库类型", required = false)
        @QueryParam("aliasName")
        aliasName: String?,
        @ApiParam("第几页", required = false, defaultValue = "1")
        @QueryParam("page")
        page: Int?,
        @ApiParam("每页多少条", required = false, defaultValue = "20")
        @QueryParam("pageSize")
        pageSize: Int?
    ): Result<RepositoryPage<RepositoryInfoWithPermission>>

    @ApiOperation("代码库列表")
    @GET
    @Path("/{projectId}/hasPermissionList")
    fun hasPermissionList(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("仓库类型", required = false)
        @QueryParam("repositoryType")
        repositoryType: ScmType?,
        @ApiParam("对应权限", required = true, defaultValue = "")
        @QueryParam("permission")
        permission: Permission,
        @ApiParam("第几页", required = false, defaultValue = "1")
        @QueryParam("page")
        page: Int?,
        @ApiParam("每页多少条", required = false, defaultValue = "20")
        @QueryParam("pageSize")
        pageSize: Int?
    ): Result<Page<RepositoryInfo>>

    @ApiOperation("删除代码库")
    @DELETE
    @Path("/{projectId}/{repositoryHashId}")
    fun delete(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = true)
        @PathParam("repositoryHashId")
        repositoryHashId: String
    ): Result<Boolean>

    @ApiOperation("根据构建ID获取提交记录")
    @GET
    @Path("/{buildId}/commit/get/record")
    fun getCommit(
        @ApiParam(value = "构建ID", required = true)
        @PathParam("buildId")
        buildId: String
    ): Result<List<CommitResponse>>

    @ApiOperation("锁定代码库")
    @PUT
    @Path("/{projectId}/{repositoryHashId}/lock")
    fun lock(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = true)
        @PathParam("repositoryHashId")
        repositoryHashId: String
    ): Result<Boolean>

    @ApiOperation("解锁代码库")
    @PUT
    @Path("/{projectId}/{repositoryHashId}/unlock")
    fun unlock(
        @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
        @HeaderParam(AUTH_HEADER_USER_ID)
        userId: String,
        @ApiParam("项目ID", required = true)
        @PathParam("projectId")
        projectId: String,
        @ApiParam("代码库哈希ID", required = true)
        @PathParam("repositoryHashId")
        repositoryHashId: String
    ): Result<Boolean>
//
//
//    @ApiOperation("是否拥有创建代码库权限")
// //    @Path("/{projectId}/hasCreatePermission")
//    @Path("/projectId/{projectId}/hasCreatePermission")
//    @GET
//    fun hasCreatePermissionV2(
//            @ApiParam("用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String
//    ): Result<Boolean>
//
//    @ApiOperation("是否拥有创建代码库别名")
// //    @Path("/{projectId}/hasAliasName")
//    @Path("/projectId/{projectId}/hasAliasName")
//    @GET
//    fun hasAliasNameV2(
//            @ApiParam("用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = false)
//            @QueryParam("repositoryHashId")
//            repositoryHashId: String?,
//            @ApiParam("代码库别名", required = true)
//            @QueryParam("aliasName")
//            aliasName: String
//    ): Result<Boolean>
//
//    @ApiOperation("关联代码库")
//    @POST
// //    @Path("/{projectId}/")
//    @Path("/projectId/{projectId}/")
//    fun createV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam(value = "代码库模型", required = true)
//            repository: Repository
//    ): Result<RepositoryId>
//
//    @ApiOperation("获取代码库详情")
//    @GET
// //    @Path("/{projectId}/{repositoryId}/")
//    @Path("/projectId/{projectId}/repositoryId/{repositoryId}/")
//    fun getV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = true)
//            @PathParam("repositoryId")
//            repositoryId: String,
//            @ApiParam("代码库请求类型", required = true)
//            @QueryParam("repositoryType")
//            repositoryType: RepositoryType?
//    ): Result<Repository>
//
//    @ApiOperation("编辑关联代码库")
//    @PUT
// //    @Path("/{projectId}/{repositoryHashId}/")
//    @Path("/projectId/{projectId}/repositoryHashId/{repositoryHashId}/")
//    fun editV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = true)
//            @PathParam("repositoryHashId")
//            repositoryHashId: String,
//            @ApiParam(value = "代码库模型", required = true)
//            repository: Repository
//    ): Result<Boolean>
//
//    @ApiOperation("代码库列表")
//    @GET
// //    @Path("/{projectId}/")
//    @Path("/projectId/{projectId}/")
//    fun listV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("仓库类型", required = false)
//            @QueryParam("repositoryType")
//            repositoryType: ScmType?,
//            @ApiParam("第几页", required = false, defaultValue = "1")
//            @QueryParam("page")
//            page: Int?,
//            @ApiParam("每页多少条", required = false, defaultValue = "20")
//            @QueryParam("pageSize")
//            pageSize: Int?
//    ): Result<RepositoryPage<RepositoryInfoWithPermission>>
//
//    @ApiOperation("代码库列表")
//    @GET
// //    @Path("/{projectId}/hasPermissionList")
//    @Path("/projectId/{projectId}/hasPermissionList")
//    fun hasPermissionListV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("仓库类型", required = false)
//            @QueryParam("repositoryType")
//            repositoryType: ScmType?,
//            @ApiParam("对应权限", required = true, defaultValue = "")
//            @QueryParam("permission")
//            permission: Permission,
//            @ApiParam("第几页", required = false, defaultValue = "1")
//            @QueryParam("page")
//            page: Int?,
//            @ApiParam("每页多少条", required = false, defaultValue = "20")
//            @QueryParam("pageSize")
//            pageSize: Int?
//    ): Result<Page<RepositoryInfo>>
//
//    @ApiOperation("删除代码库")
//    @DELETE
// //    @Path("/{projectId}/{repositoryHashId}")
//    @Path("/projectId/{projectId}/repositoryHashId/{repositoryHashId}")
//    fun deleteV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = true)
//            @PathParam("repositoryHashId")
//            repositoryHashId: String
//    ): Result<Boolean>
//
//    @ApiOperation("根据构建ID获取提交记录")
//    @GET
// //    @Path("/{buildId}/commit/get/record")
//    @Path("/buildId/{buildId}/commit/get/record")
//    fun getCommitV2(
//            @ApiParam(value = "构建ID", required = true)
//            @PathParam("buildId")
//            buildId: String
//    ): Result<List<CommitResponse>>
//
//    @ApiOperation("锁定代码库")
//    @PUT
// //    @Path("/{projectId}/{repositoryHashId}/lock")
//    @Path("/projectId/{projectId}/repositoryHashId/{repositoryHashId}/lock")
//    fun lockV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = true)
//            @PathParam("repositoryHashId")
//            repositoryHashId: String
//    ): Result<Boolean>
//
//    @ApiOperation("代码库列表根据别名模糊查询")
//    @GET
// //    @Path("/{projectId}/search/")
//    @Path("/projectId/{projectId}/search/")
//    fun fuzzySearchByAliasNameV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("仓库类型", required = false)
//            @QueryParam("repositoryType")
//            repositoryType: ScmType?,
//            @ApiParam("仓库类型", required = false)
//            @QueryParam("aliasName")
//            aliasName: String?,
//            @ApiParam("第几页", required = false, defaultValue = "1")
//            @QueryParam("page")
//            page: Int?,
//            @ApiParam("每页多少条", required = false, defaultValue = "20")
//            @QueryParam("pageSize")
//            pageSize: Int?
//    ): Result<RepositoryPage<RepositoryInfoWithPermission>>
//
//    @ApiOperation("解锁代码库")
//    @PUT
// //    @Path("/{projectId}/{repositoryHashId}/unlock")
//    @Path("/projectId/{projectId}/repositoryHashId/{repositoryHashId}/unlock")
//    fun unlockV2(
//            @ApiParam(value = "用户ID", required = true, defaultValue = AUTH_HEADER_USER_ID_DEFAULT_VALUE)
//            @HeaderParam(AUTH_HEADER_USER_ID)
//            userId: String,
//            @ApiParam("项目ID", required = true)
//            @PathParam("projectId")
//            projectId: String,
//            @ApiParam("代码库哈希ID", required = true)
//            @PathParam("repositoryHashId")
//            repositoryHashId: String
//    ): Result<Boolean>
}