/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.tencent.devops.store.service.image

import com.tencent.devops.artifactory.api.service.ServiceImageManageResource
import com.tencent.devops.common.client.Client
import com.tencent.devops.notify.api.service.ServiceNotifyMessageTemplateResource
import com.tencent.devops.notify.pojo.SendNotifyMessageTemplateRequest
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.beans.factory.annotation.Value
import org.springframework.cloud.context.config.annotation.RefreshScope
import org.springframework.stereotype.Service

/**
 * @Description
 * @Date 2019/11/21
 * @Version 1.0
 */

@RefreshScope
@Service
class SupportService @Autowired constructor(
    private val client: Client
) {
    private val logger = LoggerFactory.getLogger(SupportService::class.java)

    fun getIconDataByLogoUrl(
        logoUrl: String
    ): String? {
        try {
            val iconData = client.get(ServiceImageManageResource::class).compressImage(logoUrl, 18, 18).data
            logger.info("the iconData is :$iconData")
            return iconData
        } catch (e: Exception) {
            logger.error("compressImage error is :$e", e)
        }
        return null
    }

    @Value("\${store.imageExecuteNullNotifyTplCode}")
    private lateinit var imageExecuteNullNotifyTplCode: String

    @Value("\${store.imageAdminUsers}")
    private val imageAdminUsersStr: String? = null

    fun sendImageExecuteNullToManagers(titleParams: Map<String, String>?, bodyParams: Map<String, String>?) {
        val receivers = imageAdminUsersStr!!.trim().split(";").toMutableSet()
        val sendNotifyMessageTemplateRequest = SendNotifyMessageTemplateRequest(
            templateCode = imageExecuteNullNotifyTplCode,
            receivers = receivers,
            cc = receivers,
            titleParams = titleParams,
            bodyParams = bodyParams
        )
        val sendNotifyResult = client.get(ServiceNotifyMessageTemplateResource::class)
            .sendNotifyMessageByTemplate(sendNotifyMessageTemplateRequest)
        logger.info("sendNotifyResult is:$sendNotifyResult")
    }
}
