/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.tencent.devops.websocket.handler

import com.tencent.devops.common.api.auth.AUTH_HEADER_DEVOPS_USER_ID
import com.tencent.devops.common.redis.RedisOperation
import com.tencent.devops.common.websocket.utils.RedisUtlis
import com.tencent.devops.websocket.servcie.WebsocketService
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.server.ServerHttpRequest
import org.springframework.http.server.ServerHttpResponse
import org.springframework.http.server.ServletServerHttpRequest
import org.springframework.stereotype.Component
import org.springframework.web.socket.WebSocketHandler
import org.springframework.web.socket.server.HandshakeInterceptor

@Component
class BKHandshakeInterceptor @Autowired constructor(
    val redisOperation: RedisOperation,
    val websocketService: WebsocketService
) : HandshakeInterceptor {
    companion object {
        private val logger = LoggerFactory.getLogger(this::class.java)
    }

    override fun afterHandshake(
        request: ServerHttpRequest?,
        response: ServerHttpResponse?,
        wsHandler: WebSocketHandler?,
        exception: Exception?
    ) {
        if (request is ServletServerHttpRequest) {
            val sessionId = request.servletRequest.getParameter("sessionId")
            var userId = request.servletRequest.getHeader(AUTH_HEADER_DEVOPS_USER_ID)
            if (userId != null && sessionId != null) {
                websocketService.addCacheSession(sessionId)
                RedisUtlis.writeSessionIdByRedis(redisOperation, userId, sessionId)
                logger.info(
                    "[WebSocket]-[$userId]-[$sessionId]-连接成功,redisData:${RedisUtlis.getSessionIdByUserId(
                        redisOperation,
                        userId
                    )}"
                )
                websocketService.createTimeoutSession(sessionId, userId)
            }
        }
    }

    override fun beforeHandshake(
        request: ServerHttpRequest?,
        response: ServerHttpResponse?,
        wsHandler: WebSocketHandler?,
        attributes: MutableMap<String, Any>?
    ): Boolean {
        return true
    }
}