/*
 * Tencent is pleased to support the open source community by making BK-CI 蓝鲸持续集成平台 available.
 *
 * Copyright (C) 2019 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * BK-CI 蓝鲸持续集成平台 is licensed under the MIT license.
 *
 * A copy of the MIT License is included in this file.
 *
 *
 * Terms of the MIT License:
 * ---------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.tencent.bk.codecc.defect.api;

import com.tencent.bk.codecc.defect.vo.CCNUploadStatisticVO;
import com.tencent.bk.codecc.defect.vo.UploadDUPCStatisticVO;
import com.tencent.bk.codecc.defect.vo.UploadDefectVO;
import com.tencent.devops.common.api.pojo.CodeCCResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import javax.ws.rs.Consumes;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

/**
 * 工具侧告警上报服务
 *
 * @version V1.0
 * @date 2019/5/2
 */
@Api(tags = {"SERVICE_DEFECT"}, description = "工具侧告警上报服务接口")
@Path("/build/defects")
@Produces(MediaType.APPLICATION_JSON)
@Consumes(MediaType.APPLICATION_JSON)
public interface BuildDefectRestResource
{
    @ApiOperation("工具侧上报告警")
    @Path("/")
    @POST
    CodeCCResult reportDefects(
            @ApiParam(value = "告警详细信息", required = true)
            UploadDefectVO uploadDefectVO);

    @ApiOperation("工具侧上报圈复杂度分析的结果统计数据，每次分析完成时调用")
    @Path("/statistic/ccn")
    @POST
    CodeCCResult uploadCCNStatistic(
            @ApiParam(value = "圈复杂度统计结果", required = true)
            CCNUploadStatisticVO uploadStatisticVO);

    @ApiOperation("工具侧上报重复率分析的结果统计数据，每次分析完成时调用")
    @Path("/statistic/dupc")
    @POST
    CodeCCResult uploadDUPCStatistic(
            @ApiParam(value = "重复率统计结果", required = true)
            UploadDUPCStatisticVO uploadStatisticVO);
}
