import SockJS from 'sockjs-client'
const Stomp = require('stompjs/lib/stomp.js').Stomp

class TaskWebSocket {
    constructor () {
        this.errTime = 1
        this.stompClient = {}
    }

    connect (...args) {
        this.disconnect().then(this.build(...args))
    }

    disconnect () {
        return new Promise((resolve) => {
            if (this.stompClient.connected) this.stompClient.disconnect(resolve)
            else resolve()
        })
    }

    build (projectId, taskId, subscribeUrl, { success, error }) {
        const socket = new SockJS(`${window.AJAX_URL_PREFIX}/defect/websocket/user/taskLog/analysisInfo?X-DEVOPS-PROJECT-ID=${projectId}&X-DEVOPS-TASK-ID=${taskId}`)
        this.stompClient = Stomp.over(socket)
        this.stompClient.debug = null
        this.stompClient.connect({}, () => {
            this.stompClient.subscribe(subscribeUrl, (res) => {
                this.errTime = 1
                success(res)
            })
        }, (err) => {
            if (this.errTime <= 8) {
                // 由于部署原因，可能会出现需要重连的情况
                this.errTime++
                setTimeout(() => this.connect(projectId, taskId, subscribeUrl, { success, error }), 10000)
            } else {
                this.disconnect()
                error(err.message || 'websocket异常')
            }
        })
    }
}

export default new TaskWebSocket()
